Charms.Reactive |badge|
-----------------------

.. |badge| image:: https://travis-ci.org/juju-solutions/charms.reactive.svg?branch=master
    :target: https://travis-ci.org/juju-solutions/charms.reactive

This module serves as the basis for creating charms and relation
implementations using the reactive pattern. You can see its goal and vision in
`the vision document`_



The full documentation is available online at: https://charmsreactive.readthedocs.io/

.. _the vision document: https://github.com/juju-solutions/charms.reactive/blob/master/VISION.md


Usage
-----

See `Building a Charm from Layers`_ for more information on how to use the
charms.reactive framework. Also look at the `layer-basic documentation`_ for more
info on how to use the basic layer.

.. _Building a Charm from Layers: https://jujucharms.com/docs/stable/authors-charm-building
.. _layer-basic documentation: https://github.com/juju-solutions/layer-basic/blob/master/README.md

Contributing
------------

Want to contribute? Great! We're looking forward to your Pull Request. See
`HACKING.md`_ for more information about how to contribute to charmhelpers.

.. _HACKING.md: https://github.com/juju-solutions/charms.reactive/blob/master/HACKING.md
